==> micro-website-base-core-1.2.4-sources.jar: com/ptteng/sca/micro/common/client/UserAccountRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.UserAccountRelation;
import com.ptteng.micro.common.service.UserAccountRelationService;
import java.util.List;
import java.util.Map;

public class UserAccountRelationSCAClient implements UserAccountRelationService {

    private UserAccountRelationService userAccountRelationService;

	public UserAccountRelationService getUserAccountRelationService() {
		return userAccountRelationService;
	}
	
	
	public void setUserAccountRelationService(UserAccountRelationService userAccountRelationService) {
		this.userAccountRelationService =userAccountRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserAccountRelation userAccountRelation)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.insert(userAccountRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserAccountRelation> insertList(List<UserAccountRelation> userAccountRelationList)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.insertList(userAccountRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserAccountRelation userAccountRelation)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.update(userAccountRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserAccountRelation> userAccountRelationList)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.updateList(userAccountRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserAccountRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserAccountRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserAccountRelationIdsByAccount(String account,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.getUserAccountRelationIdsByAccount(account,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserAccountRelationIdsByUid(Long uid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.getUserAccountRelationIdsByUid(uid,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserAccountRelationIdsByAccount(String account)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.countUserAccountRelationIdsByAccount(account);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserAccountRelationIdsByUid(Long uid)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.countUserAccountRelationIdsByUid(uid);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserAccountRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userAccountRelationService.getUserAccountRelationIds(start, limit);
	}

	@Override
	public Integer countUserAccountRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userAccountRelationService.countUserAccountRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userAccountRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userAccountRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userAccountRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userAccountRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> micro-website-base-core-2.0.7-sources.jar: com/ptteng/sca/micro/common/client/UserAccountRelationSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.UserAccountRelation;
import com.ptteng.micro.common.service.UserAccountRelationService;
import java.util.List;
import java.util.Map;

public class UserAccountRelationSCAClient implements UserAccountRelationService {

    private UserAccountRelationService userAccountRelationService;

	public UserAccountRelationService getUserAccountRelationService() {
		return userAccountRelationService;
	}
	
	
	public void setUserAccountRelationService(UserAccountRelationService userAccountRelationService) {
		this.userAccountRelationService =userAccountRelationService;
	}
	
	
			   
		@Override
		public Long insert(UserAccountRelation userAccountRelation)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.insert(userAccountRelation);
		          
		
		}	
		  
    	   
		@Override
		public List<UserAccountRelation> insertList(List<UserAccountRelation> userAccountRelationList)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.insertList(userAccountRelationList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(UserAccountRelation userAccountRelation)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.update(userAccountRelation);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<UserAccountRelation> userAccountRelationList)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.updateList(userAccountRelationList);
		          
		
		}	
		  
    	   
		@Override
		public UserAccountRelation getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<UserAccountRelation> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserAccountRelationIdsByAccount(String account,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.getUserAccountRelationIdsByAccount(account,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getUserAccountRelationIdsByUid(Long uid,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.getUserAccountRelationIdsByUid(uid,start,limit);
	
	
	}

    @Override
    public List<Long> getUserAccountRelationIdsByUidAndType(Long uid, Integer type, Integer start, Integer limit) throws ServiceException, ServiceDaoException {
        return userAccountRelationService.getUserAccountRelationIdsByUidAndType(uid,type,start,limit);
    }

    @Override
    public Long getUserAccountRelationIdsByUidAndTypeAndAppId(Long uid, Integer type, String appId) throws ServiceException, ServiceDaoException {
        return userAccountRelationService.getUserAccountRelationIdsByUidAndTypeAndAppId(uid, type, appId);
    }


    /**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserAccountRelationIdsByAccount(String account)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.countUserAccountRelationIdsByAccount(account);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countUserAccountRelationIdsByUid(Long uid)throws ServiceException, ServiceDaoException{
		
		return userAccountRelationService.countUserAccountRelationIdsByUid(uid);
	
	
	}
	
		
	
		@Override
	public List<Long> getUserAccountRelationIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userAccountRelationService.getUserAccountRelationIds(start, limit);
	}

	@Override
	public Integer countUserAccountRelationIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userAccountRelationService.countUserAccountRelationIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userAccountRelationService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return userAccountRelationService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   userAccountRelationService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.userAccountRelationService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}
